<?php

namespace Focus\Salesman\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Focus\Salesman\Interfaces\SalesmanRepositoryInterface;

class SalesmanPublicController extends BaseController
{
    // use SalesmanWorkflow;

    /**
     * Constructor.
     *
     * @param type \Focus\Salesman\Interfaces\SalesmanRepositoryInterface $salesman
     *
     * @return type
     */
    public function __construct(SalesmanRepositoryInterface $salesman)
    {
        $this->repository = $salesman;
        parent::__construct();
    }

    /**
     * Show salesman's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $salesmen = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$salesman::$salesman.names'))
            ->view('$salesman::public.salesman.index')
            ->data(compact('$salesmen'))
            ->output();
    }

    /**
     * Show salesman's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $salesmen = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$salesman::$salesman.names'))
            ->view('$salesman::public.salesman.index')
            ->data(compact('$salesmen'))
            ->output();
    }

    /**
     * Show salesman.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $salesman = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$salesman->name . trans('$salesman::$salesman.name'))
            ->view('$salesman::public.salesman.show')
            ->data(compact('$salesman'))
            ->output();
    }

}
