<?php

namespace Focus\Salesman\Policies;

use Litepie\User\Contracts\UserPolicy;
use Focus\Salesman\Models\Salesman;

class SalesmanPolicy
{

    /**
     * Determine if the given user can view the salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function view(UserPolicy $user, Salesman $salesman)
    {
        if ($user->canDo('salesman.salesman.view') && $user->isAdmin()) {
            return true;
        }

        return $salesman->user_id == user_id() && $salesman->user_type == user_type();
    }

    /**
     * Determine if the given user can create a salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('salesman.salesman.create');
    }

    /**
     * Determine if the given user can update the given salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function update(UserPolicy $user, Salesman $salesman)
    {
        if ($user->canDo('salesman.salesman.edit') && $user->isAdmin()) {
            return true;
        }

        return $salesman->user_id == user_id() && $salesman->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Salesman $salesman)
    {
        return $salesman->user_id == user_id() && $salesman->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Salesman $salesman)
    {
        if ($user->canDo('salesman.salesman.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given salesman.
     *
     * @param UserPolicy $user
     * @param Salesman $salesman
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Salesman $salesman)
    {
        if ($user->canDo('salesman.salesman.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
