<?php

namespace Focus\Salesman\Providers;

use Illuminate\Support\ServiceProvider;

class SalesmanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'salesman');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'salesman');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.salesman', function ($app) {
            return $this->app->make('Focus\Salesman\Salesman');
        });

                // Bind Salesman to repository
        $this->app->bind(
            'Focus\Salesman\Interfaces\SalesmanRepositoryInterface',
            \Focus\Salesman\Repositories\Eloquent\SalesmanRepository::class
        );

        $this->app->register(\Focus\Salesman\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Salesman\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.salesman'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/salesman.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/salesman')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/salesman')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
